.. _crunchyfrog-schema:

Schema Information
==================

The navigator displays the schema of a datasource in a hierarchical
structure. Top level elements are the datasources.

.. note::

   Uncollapsing and collapsing a node doesn't result in refreshed
   data. To refresh a node right-click on that node and choose
   :menuselection:`Refresh` from the popup menu.

Depending on the selected element a right click on the node will
present a popup menu with commands for that node.
